@@ -29,12 +29,11 @@ class BWSchedulerPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    BWSchedulerPlugin(QObject *parent, const QVariantList &args);
+    BWSchedulerPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~BWSchedulerPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
 public Q_SLOTS:
     void timerTriggered();
